Components › Table — Stisla

# Table

Example of some Bootstrap table components.

#### Simple Table

# | Name | Created At | Status | Action
--- | --- | --- | --- | ---
1 | Irwansyah Saputra | 2017-01-09 | Active | Detail
2 | Hasan Basri | 2017-01-09 | Active | Detail
3 | Kusnadi | 2017-01-11 | Not Active | Detail
4 | Rizal Fakhri | 2017-01-11 | Active | Detail

#### Full Width

# | Name | Created At | Status | Action
--- | --- | --- | --- | ---
1 | Irwansyah Saputra | 2017-01-09 | Active | Detail
2 | Hasan Basri | 2017-01-09 | Active | Detail
3 | Kusnadi | 2017-01-11 | Not Active | Detail
4 | Rizal Fakhri | 2017-01-11 | Active | Detail
5 | Isnap Kiswandi | 2017-01-17 | Active | Detail

#### Advanced Table

| Task Name | Progress | Members | Due Date | Status | Action
--- | --- | --- | --- | --- | --- | ---
| Create a mobile app |  |  | 2018-01-20 | Completed | Detail
| Redesign homepage |  |  | 2018-04-10 | Todo | Detail
| Backup database |  |  | 2018-01-29 | In Progress | Detail
| Input data |  |  | 2018-01-16 | Completed | Detail

#### Sortable Table

| Task Name | Progress | Members | Due Date | Status | Action
--- | --- | --- | --- | --- | --- | ---
| Create a mobile app |  |  | 2018-01-20 | Completed | Detail
| Redesign homepage |  |  | 2018-04-10 | Todo | Detail
| Backup database |  |  | 2018-01-29 | In Progress | Detail
| Input data |  |  | 2018-01-16 | Completed | Detail